Struct bevy_notify::Toast
source · pub struct Toast { /* private fields */ }Expand description
Single notification or toast
Implementations
sourceimpl Toast
impl Toast
sourcepub fn basic(caption: impl Into<String>) -> Toast
pub fn basic(caption: impl Into<String>) -> Toast
Creates new basic toast, can be closed by default.
sourcepub fn success(caption: impl Into<String>) -> Toast
pub fn success(caption: impl Into<String>) -> Toast
Creates new success toast, can be closed by default.
sourcepub fn info(caption: impl Into<String>) -> Toast
pub fn info(caption: impl Into<String>) -> Toast
Creates new info toast, can be closed by default.
sourcepub fn warning(caption: impl Into<String>) -> Toast
pub fn warning(caption: impl Into<String>) -> Toast
Creates new warning toast, can be closed by default.
sourcepub fn error(caption: impl Into<String>) -> Toast
pub fn error(caption: impl Into<String>) -> Toast
Creates new error toast, can not be closed by default.
sourcepub fn set_options(&mut self, options: ToastOptions) -> &mut Toast
pub fn set_options(&mut self, options: ToastOptions) -> &mut Toast
Set the options with a ToastOptions
sourcepub fn set_level(&mut self, level: ToastLevel) -> &mut Toast
pub fn set_level(&mut self, level: ToastLevel) -> &mut Toast
Change the level of the toast
sourcepub fn set_closable(&mut self, closable: bool) -> &mut Toast
pub fn set_closable(&mut self, closable: bool) -> &mut Toast
Can use close the toast?
sourcepub fn set_duration(&mut self, duration: Option<Duration>) -> &mut Toast
pub fn set_duration(&mut self, duration: Option<Duration>) -> &mut Toast
In what time should the toast expire? Set to None for no expiry.
sourcepub fn set_height(&mut self, height: f32) -> &mut Toast
pub fn set_height(&mut self, height: f32) -> &mut Toast
Toast’s box height