Struct bevy_notify::Toasts

source ·
pub struct Toasts { /* private fields */ }
Main notifications collector.

Usage

You need to create Toasts once and call .show(ctx) in every frame.

use egui_notify::Toasts;

let mut t = Toasts::default();
t.info("Hello, World!").set_duration(Duration::from_secs(5)).set_closable(true);
// More app code
t.show(ctx);

Implementations

Creates new Toasts instance.

Adds new toast to the collection. By default adds toast at the end of the list, can be changed with self.reverse.

Dismisses the oldest toast

Dismisses the most recent toast

Dismisses all toasts

Shortcut for adding a toast with info success.

Shortcut for adding a toast with info level.

Shortcut for adding a toast with warning level.

Shortcut for adding a toast with error level.

Shortcut for adding a toast with no level.

Should toasts be added in reverse order?

Where toasts should appear.

Sets spacing between adjacent toasts.

Margin or distance from screen to toasts’ bounding boxes

Padding or distance from toasts’ bounding boxes to inner contents.

Displays toast queue